@@ -7,6 +7,7 @@
 from splinter.driver.webdriver.firefox import WebDriver as FirefoxWebDriver
 from splinter.driver.webdriver.remote import WebDriver as RemoteWebDriver
 from splinter.driver.webdriver.chrome import WebDriver as ChromeWebDriver
+from splinter.driver.webdriver.phantomjs import WebDriver as PhantomJSWebDriver
 from splinter.exceptions import DriverNotFoundError
 
 
@@ -14,6 +15,7 @@ _DRIVERS = {
     'firefox': FirefoxWebDriver,
     'remote': RemoteWebDriver,
     'chrome': ChromeWebDriver,
+    'phantomjs': PhantomJSWebDriver,
 }
 
 try:
