@@ -134,7 +134,7 @@ class DriverAPI(RequestHandler):
 
     def find_by_name(self, name):
         """
-        Finds elements in current page by them name.
+        Finds elements in current page by their name.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`.
         """
@@ -150,7 +150,7 @@ class DriverAPI(RequestHandler):
 
     def find_by_value(self, value):
         """
-        Finds elements in current page by them value.
+        Finds elements in current page by their value.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
         """
@@ -174,7 +174,7 @@ class DriverAPI(RequestHandler):
 
     def find_link_by_partial_href(self, partial_href):
         """
-        Find links by looking for a partial ``str`` in them href attribute.
+        Find links by looking for a partial ``str`` in their href attribute.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
         """
@@ -182,7 +182,7 @@ class DriverAPI(RequestHandler):
 
     def find_link_by_text(self, text):
         """
-        Find links querying for they text.
+        Find links querying for their text.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
         """
@@ -190,7 +190,7 @@ class DriverAPI(RequestHandler):
 
     def find_link_by_partial_text(self, partial_text):
         """
-        Find links by looking for a partial ``str`` in them text.
+        Find links by looking for a partial ``str`` in their text.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
         """
@@ -198,7 +198,7 @@ class DriverAPI(RequestHandler):
 
     def find_option_by_value(self, value):
         """
-        Finds ``<option>`` elements by them value.
+        Finds ``<option>`` elements by their value.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
         """
@@ -206,7 +206,7 @@ class DriverAPI(RequestHandler):
 
     def find_option_by_text(self, text):
         """
-        Finds ``<option>`` elements by them text.
+        Finds ``<option>`` elements by their text.
 
         Returns an instance of :class:`ElementList <splinter.element_list.ElementList>`
         """
@@ -538,5 +538,15 @@ class ElementAPI(object):
         """
         raise NotImplementedError
 
+    def select(self, value, slowly=False):
+        """
+        Selects an ``<option>`` element in the element using the ``value`` of the ``<option>``.
+
+        Example:
+
+            >>> element..select("NY")
+        """
+        raise NotImplementedError
+
     def __getitem__(self, attribute):
         raise NotImplementedError
