@@ -330,6 +330,9 @@ class WebDriverElement(ElementAPI):
     def fill(self, value):
         self.value = value
 
+    def select(self, value):
+        self.find_by_xpath('//select[@name="%s"]/option[@value="%s"]' % (self["name"], value))._element.click()
+
     def type(self, value, slowly=False):
         if slowly:
             return TypeIterator(self._element, value)
