@@ -14,18 +14,16 @@ class WebDriver(BaseWebDriver):
 
     driver_name = "Chrome"
 
-    def __init__(self, user_agent=None):
-        self._patch_subprocess()
+    def __init__(self, user_agent=None, wait_time=2):
         options = Options()
 
         if user_agent is not None:
             options.add_argument("--user-agent=" + user_agent)
 
         self.driver = Chrome(chrome_options=options)
-        self._unpatch_subprocess()
 
         self.element_class = WebDriverElement
 
         self._cookie_manager = ChromeCookieManager(self.driver)
 
-        super(WebDriver, self).__init__()
+        super(WebDriver, self).__init__(wait_time)
